@@ -25,72 +25,63 @@ class DescribeLiveUserDomainsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'live', '2016-11-01', 'DescribeLiveUserDomains','live')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_PageNumber(self):
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_SecurityToken(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_PageSize(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_RegionName(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_RegionName(self): # String
 		return self.get_query_params().get('RegionName')
 
-	def set_RegionName(self,RegionName):
-		self.add_query_param('RegionName',RegionName)
-
-	def get_Tag(self):
+	def set_RegionName(self, RegionName):  # String
+		self.add_query_param('RegionName', RegionName)
+	def get_Tags(self): # RepeatList
 		return self.get_query_params().get('Tag')
 
-	def set_Tag(self, Tags):
-		for depth1 in range(len(Tags)):
-			if Tags[depth1].get('Value') is not None:
-				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
-			if Tags[depth1].get('Key') is not None:
-				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))
-
-	def get_DomainName(self):
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_OwnerId(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_DomainStatus(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_DomainStatus(self): # String
 		return self.get_query_params().get('DomainStatus')
 
-	def set_DomainStatus(self,DomainStatus):
-		self.add_query_param('DomainStatus',DomainStatus)
-
-	def get_DomainSearchType(self):
+	def set_DomainStatus(self, DomainStatus):  # String
+		self.add_query_param('DomainStatus', DomainStatus)
+	def get_DomainSearchType(self): # String
 		return self.get_query_params().get('DomainSearchType')
 
-	def set_DomainSearchType(self,DomainSearchType):
-		self.add_query_param('DomainSearchType',DomainSearchType)
-
-	def get_LiveDomainType(self):
+	def set_DomainSearchType(self, DomainSearchType):  # String
+		self.add_query_param('DomainSearchType', DomainSearchType)
+	def get_LiveDomainType(self): # String
 		return self.get_query_params().get('LiveDomainType')
 
-	def set_LiveDomainType(self,LiveDomainType):
-		self.add_query_param('LiveDomainType',LiveDomainType)
\ No newline at end of file
+	def set_LiveDomainType(self, LiveDomainType):  # String
+		self.add_query_param('LiveDomainType', LiveDomainType)
